{% extends "main.html" %}

{% block content %}
<h1 id="search">Search Results</h1>

<form id="content_search" action="search.html">
      <input name="q" id="mkdocs-search-query" type="text" class="search_input search-query ui-autocomplete-input" >
      <input type="submit" class="search-submit" value="Search">
</form>

<div id="mkdocs-search-results" class="search-results">
    Sorry, page not found.
</div>

{% endblock %}
